[tracker/wip/carlosg/parallel-installable: 1/3] tests: Update CLI tests to use tracker3 tool



commit 314db2cb2b4f706098f72d272c74a6293d724886
Author: Carlos Garnacho <carlosg gnome org>
Date:   Sun Mar 8 15:12:38 2020 +0100

    tests: Update CLI tests to use tracker3 tool

 tests/functional-tests/cli.py | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)
---
diff --git a/tests/functional-tests/cli.py b/tests/functional-tests/cli.py
index 199be2470..83c651b43 100644
--- a/tests/functional-tests/cli.py
+++ b/tests/functional-tests/cli.py
@@ -30,26 +30,26 @@ class TestCli(fixtures.TrackerCommandLineTestCase):
     def test_version(self):
         """Check we're testing the correct version of the CLI"""
         output = self.run_cli(
-            ['tracker', '--version'])
+            ['tracker3', '--version'])
 
         version_line = output.splitlines()[0]
         expected_version_line = 'Tracker %s' % configuration.tracker_version()
         self.assertEqual(version_line, expected_version_line)
 
     def test_create_local_database(self):
         """Create a database using `tracker endpoint` for local testing"""
 
         with self.tmpdir() as tmpdir:
             ontology_path = configuration.ontologies_dir()
 
             # Create the database
             self.run_cli(
-                ['tracker', 'endpoint', '--database', tmpdir,
+                ['tracker3', 'endpoint', '--database', tmpdir,
                  '--ontology-path', ontology_path])
 
             # Sanity check that it works.
             self.run_cli(
-                ['tracker', 'sparql', '--database', tmpdir,
+                ['tracker3', 'sparql', '--database', tmpdir,
                  '--query', 'ASK { ?u a rdfs:Resource }'])
 
     def test_export(self):
@@ -61,10 +61,10 @@ class TestCli(fixtures.TrackerCommandLineTestCase):
             # Create a database and export it as Turtle.
             # We don't validate the output in this test, but we should.
             self.run_cli(
-                ['tracker', 'endpoint', '--database', tmpdir,
+                ['tracker3', 'endpoint', '--database', tmpdir,
                  '--ontology-path', ontology_path])
             self.run_cli(
-                ['tracker', 'export', '--database', tmpdir]);
+                ['tracker3', 'export', '--database', tmpdir]);
 
     def test_import(self):
         """Import a Turtle file into a Tracker database."""
@@ -75,10 +75,10 @@ class TestCli(fixtures.TrackerCommandLineTestCase):
             ontology_path = configuration.ontologies_dir()
 
             self.run_cli(
-                ['tracker', 'endpoint', '--database', tmpdir,
+                ['tracker3', 'endpoint', '--database', tmpdir,
                  '--ontology-path', ontology_path])
             self.run_cli(
-                ['tracker', 'import', '--database', tmpdir, testdata]);
+                ['tracker3', 'import', '--database', tmpdir, testdata]);
 
 
 if __name__ == '__main__':
@@ -30,26 +30,26 @@ class TestCli(fixtures.TrackerCommandLineTestCase):
 
     def test_create_local_database(self):
-        """Create a database using `tracker endpoint` for local testing"""
+        """Create a database using `tracker3 endpoint` for local testing"""
 
         with self.tmpdir() as tmpdir:


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]